package com.me.brickbuster.entity;

import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer.ShapeType;
import com.badlogic.gdx.math.Vector2;
import com.me.brickbuster.entity.powerup.PowerUp;
import com.me.brickbuster.state.PlayState;

public class Brick extends Entity {

	public static final Color BLOCK_COLOR = Color.FOREST;
	public static final int BLOCK_WIDTH = 50;
	public static final int BLOCK_HEIGHT = 20;

	private Class<? extends PowerUp> powerUpType;

	private Vector2[] vertices;

	public Brick(PlayState state, Class<? extends PowerUp> powerUpType, int x, int y) {
		super(state, x, y);
		this.powerUpType = powerUpType;

		this.vertices = new Vector2[] {
			new Vector2(x, y),
			new Vector2(x + BLOCK_WIDTH, y),
			new Vector2(x + BLOCK_WIDTH, y + BLOCK_HEIGHT),
			new Vector2(x, y + BLOCK_HEIGHT)
		};
	}

	@Override
	public void render(ShapeRenderer sr) {
		sr.begin(ShapeType.Filled);
		sr.setColor(BLOCK_COLOR);
		sr.rect(getX(), getY(), BLOCK_WIDTH, BLOCK_HEIGHT);
		sr.end();
	}

	@Override
	public void update(float dt) {
	}

	public boolean hit() {
		if (state.bricks.size()-1 <= Ball.BLOCKS_FOR_BOOST) {
			for (Ball ball : state.balls) {
				ball.setSpeed(Ball.BOOST_SPEED);
			}
		}

		if (powerUpType != null) {
			try {
				PowerUp powerUp = powerUpType.getConstructor(PlayState.class, Brick.class).newInstance(state, this);
				state.powerUps.add(powerUp);
			} catch(Exception e) {
				System.out.println("Error spawning powerup: " + e.getMessage());
			}
		}
		return true;
	}

	public Vector2[] getVertices() {
		return vertices;
	}

}
