package com.me.brickbuster.entity;

import com.badlogic.gdx.Gdx;
import com.badlogic.gdx.Input;
import com.badlogic.gdx.graphics.Color;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer;
import com.badlogic.gdx.graphics.glutils.ShapeRenderer.ShapeType;
import com.badlogic.gdx.math.Vector2;
import com.me.brickbuster.BrickBuster;
import com.me.brickbuster.state.PlayState;
import net.dermetfan.utils.Pair;

public class Paddle extends Entity {

	public static final Color PADDLE_COLOR = Color.BLACK;
	public static final int DEFAULT_WIDTH = 100;
	public static final int PADDLE_HEIGHT = 10;
	public static final int PADDLE_Y = 15;
	public static final int PADDLE_SPEED = 375;

	private int width = DEFAULT_WIDTH;
	private boolean sticky = false;

	public Paddle(PlayState brickBuster) {
		super(brickBuster, BrickBuster.WIDTH / 2, PADDLE_Y);
	}

	@Override
	public void render(ShapeRenderer sr) {
		sr.begin(ShapeType.Filled);
		sr.setColor(sticky? Color.GRAY : PADDLE_COLOR);
		sr.rect(getX() - width/2, getY(), width, PADDLE_HEIGHT);
		sr.end();
	}

	@Override
	public void update(float dt) {
		if (Gdx.input.isKeyPressed(Input.Keys.LEFT)) {
			if (pos.x - width/2 - PADDLE_SPEED * dt < 0) {
				setX(width/2);
				return;
			}
			pos.x = pos.x - PADDLE_SPEED * dt;

			for (Ball ball : state.balls) {
				if (ball.isStuck()) {
					ball.setX(ball.getX() - PADDLE_SPEED * dt);
				}
			}
		}
		if (Gdx.input.isKeyPressed(Input.Keys.RIGHT)) {
			if (pos.x + width/2 + PADDLE_SPEED * dt > BrickBuster.WIDTH) {
				setX(BrickBuster.WIDTH - width/2);
				return;
			}
			pos.x = pos.x + PADDLE_SPEED * dt;

			for (Ball ball : state.balls) {
				if (ball.isStuck()) {
					ball.setX(ball.getX() + PADDLE_SPEED * dt);
				}
			}
		}
	}

	public Pair<Vector2, Vector2> getTopEdge() {
		return new Pair<Vector2, Vector2>(
				new Vector2(pos.x - width/2, pos.y + PADDLE_HEIGHT),
				new Vector2(pos.x + width/2, pos.y + PADDLE_HEIGHT)
		);
	}

	public int getWidth() {
		return width;
	}

	public void setWidth(int width) {
		this.width = width;
	}

	public boolean isSticky() {
		return sticky;
	}

	public void setSticky(boolean sticky) {
		this.sticky = sticky;
	}




}
